#!/usr/bin/python3

import json
import argparse
import requests

parser = argparse.ArgumentParser(description='Create a Redmine issue from Svacer hook')

parser.add_argument('redmine_url', help='Redmine server URL')

# project ID can be found in project settings or got from URL (/projects/<id_is_here>)
parser.add_argument('project_id', help='ID of the project to create issue')

# Enable REST API and get your token, see https://www.redmine.org/projects/redmine/wiki/rest_api#Authentication
parser.add_argument('token', help='Token for authentication')

# svacer hook arguments
parser.add_argument('url', help='Svacer URL with the warning  ')
parser.add_argument('marker', help='Path to file with marker details')

args = parser.parse_args()

# Open JSON file with marker data
with open(args.marker) as marker_file:
  data = json.load(marker_file)

  issue_type = data['warnClass']

  # Generate location as file:line from full path
  issue_location = data['file'].rsplit('/', 1)[-1] + ':' + str(data['line'])
  issue_message = data['msg']

  query = {'issue': {}}
  query['issue']['project_id'] = args.project_id  
  query['issue']['subject'] = '[SVACE] ' + issue_type + ' at ' + issue_location
  query['issue']['description'] = 'Message: ' + issue_message + '\n\n' + 'Link: ' + args.url  

  # perform http-request with api key and data in json
  # see https://www.redmine.org/projects/redmine/wiki/Rest_Issues#Creating-an-issue
  url = args.redmine_url + '/issues.json'
  headers = {'Content-Type': 'application/json', 'X-Redmine-API-Key': args.token}
  r = requests.post(url, data=json.dumps(query), headers=headers)  
